@@ -1,6 +1,6 @@
 ;;; w3m-bookmark.el --- Functions to operate bookmark file of w3m
 
-;; Copyright (C) 2001, 2002, 2003, 2005, 2006, 2007, 2008, 2009
+;; Copyright (C) 2001, 2002, 2003, 2005, 2006, 2007, 2008, 2009, 2010
 ;; TSUCHIYA Masatoshi <tsuchiya@namazu.org>
 
 ;; Authors: Shun-ichi GOTO     <gotoh@taiyo.co.jp>,
@@ -202,8 +202,7 @@ file exists, otherwise nil."
 (defun w3m-bookmark-sections ()
   "Return collection of registered sections."
   (let (sections)
-    (save-excursion
-      (set-buffer (w3m-bookmark-buffer))
+    (with-current-buffer (w3m-bookmark-buffer)
       (goto-char (point-min))
       (while (search-forward "<h2>" nil t)
 	(push (cons (buffer-substring-no-properties
@@ -255,8 +254,7 @@ file exists, otherwise nil."
 
 (defun w3m-bookmark-write-file (url title section)
   "Make new bookmark with specified spec, and save it."
-  (save-excursion
-    (set-buffer (w3m-bookmark-buffer))
+  (with-current-buffer (w3m-bookmark-buffer)
     (setq title (w3m-bookmark-safe-string
 		 title
 		 "Specified title includes unsafe character(s): %s")
@@ -416,8 +414,7 @@ With prefix argument, kill that many entries from point."
       (w3m-bookmark-view t))))
 
 (defun w3m-bookmark-kill-entries (entries)
-  (save-excursion
-    (set-buffer (w3m-bookmark-buffer t))
+  (with-current-buffer (w3m-bookmark-buffer t)
     (w3m-bookmark-verify-modtime)
     (goto-char (point-min))
     (let ((i 0))
@@ -438,8 +435,7 @@ With prefix argument, kill that many entries from point."
   "Undo some previous changes on bookmark."
   (interactive "p")
   (condition-case nil
-      (save-excursion
-	(set-buffer (w3m-bookmark-buffer t))
+      (with-current-buffer (w3m-bookmark-buffer t)
 	(w3m-bookmark-verify-modtime)
 	(undo arg)
 	(w3m-bookmark-save-buffer))
@@ -519,8 +515,7 @@ The car is used if `w3m-bookmark-mode' is nil, otherwise the cdr is used.")
   "Iteration bookmark groups/entries.
 Format as (list (\"Group name\" . (\"Entry URL\" . \"Entry name\")* )* )."
   (let ((entries nil))
-    (save-excursion
-      (set-buffer (w3m-bookmark-buffer))
+    (with-current-buffer (w3m-bookmark-buffer)
       (goto-char (point-min))
       (let (group entry beg end)
 	(while (re-search-forward "<h2>\\([^<]+\\)</h2>" nil t)
