@@ -1,6 +1,6 @@
 ;;; w3m-hist.el --- the history management system for emacs-w3m
 
-;; Copyright (C) 2001, 2002, 2003, 2004, 2005, 2008, 2009
+;; Copyright (C) 2001, 2002, 2003, 2004, 2005, 2008, 2009, 2010
 ;; TSUCHIYA Masatoshi <tsuchiya@namazu.org>
 
 ;; Author: Katsumi Yamaoka <yamaoka@jpl.org>
@@ -618,8 +618,11 @@ Data consist of the position where the window starts and the cursor
 position.  Naturally, those should be treated as buffer-local."
   (interactive)
   (when (cadar w3m-history)
-    (w3m-history-add-properties (list :window-start (window-start)
-				      :position (point)))
+    (w3m-history-add-properties
+     (list :window-start (window-start)
+	   :position (cons (count-lines (point-min) (point-at-bol))
+			   (current-column))
+	   :window-hscroll (window-hscroll)))
     (when (interactive-p)
       (message "The current cursor position saved"))))
 
@@ -636,8 +639,12 @@ it works although it may not be perfect."
 	     (when (<= start (point-max))
 	       (setq window (get-buffer-window (current-buffer) 'all-frames))
 	       (when window
-		 (set-window-start window start))
-	       (goto-char (min position (point-max)))
+		 (set-window-start window start)
+		 (set-window-hscroll
+		  window (or (w3m-history-plist-get :window-hscroll) 0)))
+	       (goto-char (point-min))
+	       (forward-line (car position))
+	       (move-to-column (cdr position))
 	       (let ((deactivate-mark nil))
 		 (run-hooks 'w3m-after-cursor-move-hook))))
 	    ((interactive-p)
